/* *
 * @file
 * Global utilities.
 *
 */
(function ($, Drupal) {
  'use strict';

  // Focus effect.
  Drupal.behaviors.loginFocus = {
    attach: function (context) {
      $('.user-login-form .form-item-name').addClass('focused');
      $(
        "input[type='text'], input[type='email'], input[type='tel'], input[type='number'], input[data-drupal-selector='edit-pass'], input[type='text'], .password-field, .password-confirm",
        '.user-login-form, .user-pass, .user-register-form, .user-form'
      )
        .focus(function () {
          $(this).parent('.js-form-item').addClass('focused');
        })
        .blur(function () {
          if ($(this).val() == '') {
            $(this).parent('.js-form-item').removeClass('focused');
          }
        });
    }
  };

  Drupal.behaviors.togglePassword = {
    attach: function (context, settings) {
      $('.user-login-form').each(function () {
        var _this = $(this);
        _this.find('.js-form-type-password').append('<span toggle="#password-field" class="toggle-password"></span>');
        _this.find('.toggle-password').on('click', function () {
          $(this).toggleClass('icon-eye-slash');
          var input = $(this).parent().find('input');
          if (input.attr('type') == 'password') {
            input.attr('type', 'text');
          } else {
            input.attr('type', 'password');
          }
        });
      });
    }
  };

  // Fill placeholder and change labels on register.
  Drupal.behaviors.registerChangePlaceholdersAndLabels = {
    attach: function (context, settings) {
      var user_login = $('.user-login-form', context);
      var user_pass = $('.user-pass', context);
      var user_register = $('.user-register-form', context);
  
      // Function to set placeholders
      function setPlaceholders(form, placeholders) {
        for (const [inputClass, placeholderText] of Object.entries(placeholders)) {
          form.find(inputClass).attr('placeholder', Drupal.t(placeholderText));
        }
      }
  
      // Set placeholders for login, recovery, and registration
      setPlaceholders(user_login, {
        '.form-item-name input': 'Enter your username',
        '.form-item-pass input': 'Enter your password',
      });
  
      setPlaceholders(user_pass, {
        '.form-item-name input': 'Enter your username or email',
      });
  
      setPlaceholders(user_register, {
        '.form-item-mail input': 'Enter your email',
        '.form-item-name input': 'Enter your username',
        '.form-item-pass-pass1 input': 'Enter your password',
        '.form-item-pass-pass2 input': 'Enter again your password',
      });
  
      // Change button classes
      user_login.find('.form-actions button.js-form-submit.form-submit').addClass('button');
      user_register.find('.form-actions button.js-form-submit.form-submit').addClass('button');
  
      // Disable buttons initially
      var submit = user_login.find(':input[type=submit]'),
          submit_pass = user_pass.find(':input[type=submit]'),
          submit_register = user_register.find(':input[type=submit]');
  
      function toggleSubmitButtons() {
        let allLoginFilled = [...user_login.find(':input[type=text], :input[type=password]')].every(el => $(el).val() !== '');
        let allPassFilled = [...user_pass.find(':input[type=text]')].every(el => $(el).val() !== '');
        let allRegisterFilled = [...user_register.find(':input[type=text], :input[type=password], :input[type=email]')].every(el => $(el).val() !== '');
  
        // Check if .password-confirm-message has a div with the class “error”
        let passwordConfirmMessage = user_register.find('.password-confirm-message');
        let hasError = passwordConfirmMessage.find('.error').length > 0;
        let hasOk = passwordConfirmMessage.find('.ok').length > 0;
  
        // The registration button is only activated if all the fields are filled in and there is NO error when confirming the password
        submit_register.prop('disabled', !(allRegisterFilled && hasOk && !hasError));
  
        // The other buttons work normally
        submit.prop('disabled', !allLoginFilled);
        submit_pass.prop('disabled', !allPassFilled);
      }
  
      // Attach events to inputs to check for changes
      user_login.find(':input').on('keydown blur input', toggleSubmitButtons);
      user_pass.find(':input').on('keydown blur input', toggleSubmitButtons);
      user_register.find(':input').on('keydown blur input', toggleSubmitButtons);
  
       // Adds an event to observe changes in the password confirmation message div
      user_register.find('.password-confirm-message').on('DOMSubtreeModified', toggleSubmitButtons);
  
      // Initial call to set button state
      toggleSubmitButtons();
    }
  };
  
  
  
})(jQuery, Drupal);
